@@ -167,7 +167,9 @@ class EcoVacsIOTMQ(ClientMQTT):
         params = {}
         params.update(args)
 
-        _LOGGER.debug("calling IOT api with {}".format(args))
+        es = datetime.datetime.now().timestamp()
+
+        _LOGGER.debug(str(es) + "| calling IOT api with {}".format(args))
 
         headers = {'User-Agent': 'Dalvik/2.1.0 (Linux; U; Android 5.1.1; A5010 Build/LMY48Z)',}
         url = (self.portal_url_format + "/iot/devmanager.do?mid=" + params['toType'] + "&did=" + params['toId'] + "&td=" + params['td'] + "&u=" + params['auth']['userid'] + "&cv=1.67.3&t=a&av=1.3.1").format(continent=self.continent)
@@ -175,12 +177,13 @@ class EcoVacsIOTMQ(ClientMQTT):
         try:  
             with requests.post(url, headers=headers, json=params, timeout=20, verify=verify_ssl) as response:
                 data = response.json()
-                _LOGGER.debug("got {}".format(data))
+                _LOGGER.debug(str(es) + "| got {}".format(data))
                 if response.status_code != 200:
-                    _LOGGER.warning("Error calling API " + str(url))
+                    _LOGGER.warning(str(es) + "| Error calling API " + str(url))
 
                 return data
-        except:
+        except requests.exceptions.RequestException as e:  # This is the correct syntax
+            _LOGGER.warning(e)
             return {}
             
     def CallCleanLogsApi(self, args, verify_ssl=True):
